@@ -7,7 +7,7 @@ from tuneflow_py.models.note import Note
 from tuneflow_py.models.song import Song
 from tuneflow_py.models.tempo import TempoEvent
 from tuneflow_py.models.time_signature import TimeSignatureEvent
-from tuneflow_py.models.track import TrackType, Track
+from tuneflow_py.models.track import TrackType, Track, TrackOutputType
 from tuneflow_py.descriptors.widget import *
 from tuneflow_py.descriptors.text import *
 from tuneflow_py.descriptors.param import *
